==> native-carousel-1.0.0.tgz: package/src/carousel.js <==
/*
* One more carousel/slideshow... this one keeps the original HTML
*/

import throttle from './throttle.js';
import {addListener, removeListener} from './moveListeners.js';

const defaults = {
	currentSlide: 0,
	selector: '.carousel-container',
	animate: true,
	animateDelay: 4000
};

class Carousel{
	constructor(config = {}){
		// merge defaults and instance configs
		Object.assign(this, defaults, config);

		// prepare reactive position setter
		let currentSlide = this.currentSlide;
		Object.defineProperty(this, 'currentSlide', {
			set: newValue => {
				if (newValue < 0) newValue = this.slides.length - 1;
				else if (newValue >= this.slides.length) newValue = 0;
				this.moveTo((currentSlide = newValue));
			},
			get: () => currentSlide
		});

		// set DOM elements
		this.container = typeof this.selector == 'string' ? document.querySelector(this.selector) : this.selector;
		this.galleryContainer = this.container.querySelector('.carousel-gallery');
		this.slides = [...this.galleryContainer.querySelectorAll('.carousel-slide')];
		this.buttons = [...this.container.querySelectorAll('.carousel-button')];

		// setup mouse and touch interaction
		this.onDrag = throttle(this, this.onDrag, 150);
		this.attachEventListeners();

		if (this.animate) this.startAnimation();
	}

	attachEventListeners(){
		// so we avoid binding everywhere
		this.toggleDrag = this.toggleDrag.bind(this);

		// buttons
		const incrementMoveTo = increment => () => {
			this.currentSlide += increment;
			this.startAnimation();
		};
		const [prevBtn, nextBtn] = this.buttons;
		prevBtn.addEventListener('click', incrementMoveTo(-1));
		nextBtn.addEventListener('click', incrementMoveTo(+1));

		// drag
		this.container.addEventListener('mousedown', this.toggleDrag);
		this.container.addEventListener('touchstart', this.toggleDrag);
	}

	startAnimation(){
		clearInterval(this.animationInterval);
		this.animationInterval = setInterval(() => this.currentSlide++, 2000);
	}

	moveTo(i){
		const parentPosition = this.galleryContainer.getBoundingClientRect();
		const nextPosition = this.slides[i].getBoundingClientRect();
		const diff = nextPosition.x - parentPosition.x;
		this.galleryContainer.style.left = -diff + 'px';
	}

	getPointerCoordinates(e){
		const isMouse = e.type.includes('mouse');
		return {
			x: isMouse ? e.pageX : e.originalEvent.touches[0].pageX,
			y: isMouse ? e.pageY : e.originalEvent.touches[0].pageY
		};
	}

	toggleDrag(e){
		const listenForDrag = e.type == 'mousedown' || e.type == 'touchstart';
		const currentLeftPosition = parseInt(this.galleryContainer.style.left || 0, 10);

		if (listenForDrag){
			this.dragParams = {
				...this.getPointerCoordinates(e),
				diff: 0,
				currentLeftPosition: currentLeftPosition
			};

			clearInterval(this.animationInterval);
			addListener('move', this.onDrag);
			addListener('up', this.toggleDrag);
		} else {
			this.dragParams = null;
			const nearestSlide = Math.round(currentLeftPosition / this.slides[0].getBoundingClientRect().width);
			this.currentSlide = Math.abs(nearestSlide);
			if (this.animate) this.startAnimation();
			removeListener('move', this.onDrag);
			removeListener('up', this.toggleDrag);
		}
	}

	onDrag(e){
		if (!this.dragParams) return;
		const pointerPosition = this.getPointerCoordinates(e);
		const diff = pointerPosition.x - this.dragParams.x;
		this.galleryContainer.style.left = this.dragParams.currentLeftPosition + diff + 'px';
	}
}

window.Carousel = Carousel;

==> native-carousel-1.0.7.tgz: package/src/carousel.js <==
/*
* One more carousel/slideshow... this one keeps the original HTML
*/

import throttle from './throttle.js';

const defaults = {
	currentSlide: 0,
	selector: '.carousel-container',
	animate: true,
	animateDelay: 4000
};

class Carousel{
	constructor(config = {}){
		// merge defaults and instance configs
		Object.assign(this, defaults, config);

		// prepare reactive position setter
		let currentSlide = this.currentSlide;
		Object.defineProperty(this, 'currentSlide', {
			set: newValue => {
				if (newValue < 0) newValue = this.slides.length - 1;
				else if (newValue >= this.slides.length) newValue = 0;
				this.moveTo((currentSlide = newValue));
			},
			get: () => currentSlide
		});

		// set DOM elements
		this.container = typeof this.selector == 'string' ? document.querySelector(this.selector) : this.selector;
		this.galleryContainer = this.container.querySelector('.carousel-gallery');
		this.slides = [...this.galleryContainer.querySelectorAll('.carousel-slide')];
		this.buttons = [...this.container.querySelectorAll('.carousel-button')];

		// setup mouse and touch interaction
		this.onDrag = throttle(this, this.onDrag, 150);
		this.attachEventListeners();

		if (this.animate) this.startAnimation();
	}

	attachEventListeners(){
		// so we avoid binding everywhere
		this.toggleDrag = this.toggleDrag.bind(this);

		// buttons
		const incrementMoveTo = increment => () => {
			this.currentSlide += increment;
			this.startAnimation();
		};
		const [prevBtn, nextBtn] = this.buttons;
		if (prevBtn) prevBtn.addEventListener('click', incrementMoveTo(-1));
		if (nextBtn) nextBtn.addEventListener('click', incrementMoveTo(+1));

		// drag
		this.container.addEventListener('mousedown', this.toggleDrag);
		this.container.addEventListener('touchstart', this.toggleDrag);
	}

	startAnimation(){
		clearInterval(this.animationInterval);
		this.animationInterval = setInterval(() => this.currentSlide++, this.animateDelay);
	}

	moveTo(i){
		const parentPosition = this.galleryContainer.getBoundingClientRect();
		const nextPosition = this.slides[i].getBoundingClientRect();
		const diff = nextPosition.x - parentPosition.x;
		this.galleryContainer.style.left = -diff + 'px';
	}

	getPointerCoordinates(e){
		const isMouse = e.type.includes('mouse');
		return {
			x: isMouse ? e.pageX : e.originalEvent.touches[0].pageX,
			y: isMouse ? e.pageY : e.originalEvent.touches[0].pageY
		};
	}

	toggleDrag(e){
		const listenForDrag = e.type == 'mousedown' || e.type == 'touchstart';
		const currentLeftPosition = parseInt(this.galleryContainer.style.left || 0, 10);

		if (listenForDrag){
			const coords = this.getPointerCoordinates(e);
			this.dragParams = {
				x: coords.x,
				y: coords.y,
				diff: 0,
				currentLeftPosition: currentLeftPosition
			};

			clearInterval(this.animationInterval);
			window.addEventListener('mousemove', this.onDrag);
			window.addEventListener('touchmove', this.onDrag);
			window.addEventListener('mouseup', this.toggleDrag);
			window.addEventListener('touchend', this.toggleDrag);
		} else {
			this.dragParams = null;
			const nearestSlide = Math.round(currentLeftPosition / this.slides[0].getBoundingClientRect().width);
			this.currentSlide = Math.abs(nearestSlide);
			if (this.animate) this.startAnimation();
			window.removeEventListener('mousemove', this.onDrag);
			window.removeEventListener('touchmove', this.onDrag);
			window.removeEventListener('mouseup', this.toggleDrag);
			window.removeEventListener('touchend', this.toggleDrag);
		}
	}

	onDrag(e){
		if (!this.dragParams) return;
		const pointerPosition = this.getPointerCoordinates(e);
		const diff = pointerPosition.x - this.dragParams.x;
		this.galleryContainer.style.left = this.dragParams.currentLeftPosition + diff + 'px';
	}
}

export default Carousel;
